@@ -239,7 +239,7 @@ func runMachineRun(ctx context.Context) error {
 	fmt.Fprintf(io.Out, " State: %s\n", state)
 
 	// wait for machine to be started
-	if err := WaitForStart(ctx, flapsClient, machine, time.Minute*5); err != nil {
+	if err := WaitForStartOrStop(ctx, flapsClient, machine, "start", time.Minute*5); err != nil {
 		return err
 	}
 
@@ -295,10 +295,20 @@ func createApp(ctx context.Context, message, name string, client *api.Client) (*
 	}, nil
 }
 
-func WaitForStart(ctx context.Context, flapsClient *flaps.Client, machine *api.Machine, timeout time.Duration) error {
+func WaitForStartOrStop(ctx context.Context, flapsClient *flaps.Client, machine *api.Machine, action string, timeout time.Duration) error {
 	waitCtx, cancel := context.WithTimeout(ctx, timeout)
 	defer cancel()
 
+	var waitOnAction string
+	switch action {
+	case "start":
+		waitOnAction = "started"
+	case "stop":
+		waitOnAction = "stopped"
+	default:
+		return fmt.Errorf("action must be either start or stop")
+	}
+
 	b := &backoff.Backoff{
 		Min:    500 * time.Millisecond,
 		Max:    2 * time.Second,
@@ -306,12 +316,12 @@ func WaitForStart(ctx context.Context, flapsClient *flaps.Client, machine *api.M
 		Jitter: false,
 	}
 	for {
-		err := flapsClient.Wait(waitCtx, machine, "started")
+		err := flapsClient.Wait(waitCtx, machine, waitOnAction)
 		switch {
 		case errors.Is(err, context.Canceled):
 			return err
 		case errors.Is(err, context.DeadlineExceeded):
-			return fmt.Errorf("timeout reached waiting for machine to start %w", err)
+			return fmt.Errorf("timeout reached waiting for machine to %s %w", waitOnAction, err)
 		case err != nil:
 			time.Sleep(b.Duration())
 			continue
@@ -392,7 +402,7 @@ func determineImage(ctx context.Context, appName string, imageOrPath string) (im
 	}
 
 	fmt.Fprintf(io.Out, "Image: %s\n", img.Tag)
-	fmt.Fprintf(io.Out, "Image size: %s\n", humanize.Bytes(uint64(img.Size)))
+	fmt.Fprintf(io.Out, "Image size: %s\n\n", humanize.Bytes(uint64(img.Size)))
 
 	return img, nil
 }
